@@ -1,10 +1,9 @@
 # SPDX-FileCopyrightText: 2023-present deepset GmbH <info@deepset.ai>
 #
 # SPDX-License-Identifier: Apache-2.0
-import logging
 from typing import Any, Dict, List, Literal, Optional
 
-from haystack import default_from_dict, default_to_dict
+from haystack import default_from_dict, default_to_dict, logging
 from haystack.dataclasses.document import ByteStream, Document
 from haystack.document_stores.errors import DocumentStoreError, DuplicateDocumentError
 from haystack.document_stores.types import DuplicatePolicy
@@ -193,7 +192,7 @@ class PgvectorDocumentStore:
             try:
                 self._connection.close()
             except Error as e:
-                logger.debug("Failed to close connection: %s", str(e))
+                logger.debug("Failed to close connection: {e}", e=str(e))
 
         conn_str = self.connection_string.resolve_value() or ""
         connection = connect(conn_str)
@@ -295,7 +294,7 @@ class PgvectorDocumentStore:
         cursor = cursor or self.cursor
 
         sql_query_str = sql_query.as_string(cursor) if not isinstance(sql_query, str) else sql_query
-        logger.debug("SQL query: %s\nParameters: %s", sql_query_str, params)
+        logger.debug("SQL query: {query}\nParameters: {parameters}", query=sql_query_str, parameters=params)
 
         try:
             result = cursor.execute(sql_query, params)
@@ -512,7 +511,7 @@ class PgvectorDocumentStore:
         sql_insert += SQL(" RETURNING id")
 
         sql_query_str = sql_insert.as_string(self.cursor) if not isinstance(sql_insert, str) else sql_insert
-        logger.debug("SQL query: %s\nParameters: %s", sql_query_str, db_documents)
+        logger.debug("SQL query: {query}\nParameters: {parameters}", query=sql_query_str, parameters=db_documents)
 
         try:
             self.cursor.executemany(sql_insert, db_documents, returning=True)
@@ -555,24 +554,14 @@ class PgvectorDocumentStore:
             db_document["blob_mime_type"] = blob.mime_type if blob and blob.mime_type else None
             db_document["meta"] = Jsonb(db_document["meta"])
 
-            if "dataframe" in db_document:
-                dataframe = db_document.pop("dataframe", None)
-                if dataframe:
-                    logger.warning(
-                        "Document %s has the `dataframe` field set. "
-                        "PgvectorDocumentStore no longer supports dataframes and this field will be ignored. "
-                        "The `dataframe` field will soon be removed from Haystack Document.",
-                        db_document["id"],
-                    )
-
             if "sparse_embedding" in db_document:
                 sparse_embedding = db_document.pop("sparse_embedding", None)
                 if sparse_embedding:
                     logger.warning(
-                        "Document %s has the `sparse_embedding` field set,"
+                        "Document {doc_id} has the `sparse_embedding` field set,"
                         "but storing sparse embeddings in Pgvector is not currently supported."
                         "The `sparse_embedding` field will be ignored.",
-                        db_document["id"],
+                        doc_id=db_document["id"],
                     )
 
             db_documents.append(db_document)
@@ -591,20 +580,11 @@ class PgvectorDocumentStore:
             blob_data = haystack_dict.pop("blob_data")
             blob_meta = haystack_dict.pop("blob_meta")
             blob_mime_type = haystack_dict.pop("blob_mime_type")
-            dataframe = haystack_dict.pop("dataframe", None)
 
             # convert the embedding to a list of floats
             if document.get("embedding") is not None:
                 haystack_dict["embedding"] = document["embedding"].tolist()
 
-            if dataframe:
-                logger.warning(
-                    "Document %s has the `dataframe` field set. "
-                    "PgvectorDocumentStore no longer supports dataframes and this field will be ignored. "
-                    "The `dataframe` field will soon be removed from Haystack Document.",
-                    haystack_dict["id"],
-                )
-
             haystack_document = Document.from_dict(haystack_dict)
 
             if blob_data:
